!-------------------------------------------------------------------------------

!                      Code_Saturne version 4.0.2
!                      --------------------------
! This file is part of Code_Saturne, a general-purpose CFD tool.
!
! Copyright (C) 1998-2015 EDF S.A.
!
! This program is free software; you can redistribute it and/or modify it under
! the terms of the GNU General Public License as published by the Free Software
! Foundation; either version 2 of the License, or (at your option) any later
! version.
!
! This program is distributed in the hope that it will be useful, but WITHOUT
! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
! FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
! details.
!
! You should have received a copy of the GNU General Public License along with
! this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
! Street, Fifth Floor, Boston, MA 02110-1301, USA.

!-------------------------------------------------------------------------------

!===============================================================================
! Purpose:
! -------

!> \file cs_user_modules.f90
!>
!> \brief User-defined module: it allows to create any user array.
!>
!> This file is compiled before all other user Fortran files.
!> To ensure this, it must not be renamed.
!>
!> The user may define an arbitrary number of modules here, even though
!> only one is defined in the example.
!
!> \cond DOXYGEN_SHOULD_SKIP_THIS

!-------------------------------------------------------------------------------

module convoutlet

  !=============================================================================

  implicit none

  !=============================================================================

  ! Example: allocatable user arrays

  integer,          dimension(:,:), allocatable :: velf
  double precision, dimension(:), allocatable :: presf

contains

  !=============================================================================

  ! Allocate arrays

  subroutine init_convoutlet_module(nfabor)
    implicit none
    ! Arguments

    integer, intent(in) :: nfabor

    ! Local variables
    integer :: ifac
    integer :: err = 0

    if (.not.allocated(velf)) then
      allocate(velf(3,nfabor), stat=err)
    endif
    if (err /= 0) then
      write (*, *) "Error allocating local memory velf."
    endif

    if (err .eq. 0 .and. .not.allocated(presf)) then
      allocate(presf(nfabor), stat=err)
    endif
    if (err /= 0) then
      write(*,*) "Error allocating local memory presf"
    endif

    if (err /= 0) then
      write (*, *) "Error allocating conv outlet arrays."
      call csexit(err)
    endif

    do ifac = 1, nfabor
      velf(1, ifac) = 0.d0
      velf(2, ifac) = 0.d0
      velf(3, ifac) = 0.d0
      presf (ifac) = 0.d0
    enddo

  end subroutine init_convoutlet_module

  !=============================================================================

  ! Free related arrays

  subroutine finalize_convoutlet_module
    implicit none

    if (allocated(velf)) then
      deallocate(velf)
    endif

    if (allocated(presf)) then
      deallocate(presf)
    endif

  end subroutine finalize_convoutlet_module

  !=============================================================================

end module convoutlet

!-------------------------------------------------------------------------------

!> (DOXYGEN_SHOULD_SKIP_THIS) \endcond
